==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ro.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Partajare federalizată",
    "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
    "Sharing %s failed, because this item is already shared with %s" : "Partajarea %s a eșuat deoarece acest element este deja partajat cu %s",
    "Not allowed to create a federated share with the same user" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator",
    "File is already shared with %s" : "Fişierul este deja partajat cu %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Partajarea %s a eşuat, nu pot găsi %s, poate serverul nu poate fi contactat.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Ai primit \"/%3$s\" ca partajare remote de la %1$s (în numele %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Ai primit \"/%3$s\" ca partajare remote de la %1$s",
    "Accept" : "Accept",
    "Decline" : "Refuză",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partajează cu mine prin #Nextcloud Federated Cloud ID, vezi %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partajează cu mine prin #Nextcloud Federated Cloud ID",
    "Federated Cloud Sharing" : "Partajare federalizata cloud",
    "Open documentation" : "Deschide documentația",
    "Allow users on this server to send shares to other servers" : "Permite utilizatorilor de pe acest server să transmită partajări către alte servere",
    "Allow users on this server to receive shares from other servers" : "Permite utilizatorilor acestui server să primească partajări de la alte servere",
    "Federated Cloud" : "Cloud federalizat",
    "Your Federated Cloud ID:" : "ID Cloud federalizat:",
    "Share it:" : "Partajează:",
    "Add to your website" : "Adaugă la site-ul tău Web",
    "Share with me via Nextcloud" : "Partajează cu mine via Nextcloud",
    "HTML Code:" : "Cod HTML:"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ro.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Remote share" : "Element partajat la distanță",
    "Remote share password" : "Parolă element partajat la distanță",
    "Cancel" : "Anulează",
    "Add remote share" : "Adaugă element partajat la distanță",
    "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
    "Server to server sharing is not enabled on this server" : "Partajarea server-server nu este activată pe acest server",
    "Not allowed to create a federated share with the same user" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator",
    "File is already shared with %s" : "Fişierul este deja partajat cu %s",
    "Could not find share" : "Nu am putut găsi partajarea",
    "Federated sharing" : "Partajare federalizată",
    "Accept" : "Accept",
    "Decline" : "Refuză",
    "Federated Cloud Sharing" : "Partajare federalizata cloud",
    "Sharing" : "Partajare",
    "Allow users on this server to receive shares from other servers" : "Permite utilizatorilor acestui server să primească partajări de la alte servere",
    "Federated Cloud" : "Cloud federalizat",
    "Your Federated Cloud ID:" : "ID Cloud federalizat:",
    "Twitter" : "Twitter",
    "Add to your website" : "Adaugă la site-ul tău Web",
    "Share with me via Nextcloud" : "Partajează cu mine via Nextcloud",
    "HTML Code:" : "Cod HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partajează cu mine prin #Nextcloud Federated Cloud ID",
    "Copy to clipboard" : "Copiază în clipboard",
    "Copied!" : "S-a copiat!",
    "Copy" : "Copiază",
    "Not supported!" : "Nu este suportat!",
    "Press ⌘-C to copy." : "Apasă ⌘-C pentru copiere.",
    "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru copiere.",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partajează cu mine prin #Nextcloud Federated Cloud ID, vezi %s",
    "Open documentation" : "Deschide documentația"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
